@@ -38,7 +38,15 @@ def get_kernel_for_cluster(cluster_uuid: str):
     raise KeyError(f"Could not find kernel spec for cluster_uuid: {cluster_uuid}")
 
 
-def get_remote_kernel_name_for_cluster(cluster_uuid, hostnames, ssh_key_fname, logger):
+def get_remote_kernel_name_for_cluster(
+    cluster_uuid,
+    hostnames,
+    logger,
+    tunnel_host,
+    tunnel_host_user,
+    cluster_user,
+    ssh_key_fname=None,
+):
     logging_prefix = f"[GetKernelNameForCluster][UUID: {cluster_uuid}]"
     logger.info(f"{logging_prefix} hostname: {hostnames}")
     # Check if a kernelspec for this cluster already exists
@@ -64,13 +72,34 @@ def get_remote_kernel_name_for_cluster(cluster_uuid, hostnames, ssh_key_fname, l
     logger.info(
         f"{logging_prefix} Couldn't find any existing kernels. Randomly selected {selected_hostname} as the kernel host."
     )
-    kernel_name = add_remote_kernel(selected_hostname, cluster_uuid, ssh_key_fname)
+    kernel_name = add_remote_kernel(
+        selected_hostname,
+        cluster_uuid,
+        cluster_user,
+        ssh_key_fname,
+        tunnel_host=tunnel_host,
+        tunnel_host_user=tunnel_host_user,
+    )
     logger.info(f"{logging_prefix} Created kernel: {kernel_name}")
     logger.info(f"{logging_prefix} Returing kernel_name: {kernel_name}")
     return kernel_name
 
 
-def add_remote_kernel(hostname, cluster_uuid, ssh_key_fname=None, dryrun=False):
+def add_remote_kernel(
+    hostname,
+    cluster_uuid,
+    cluster_user=None,
+    ssh_key_fname=None,
+    dryrun=False,
+    tunnel_host=None,
+    tunnel_host_user=None,
+):
+    # If username isn't set for hostname or tunnel_host set it to default
+    if "@" not in hostname and cluster_user:
+        hostname = f"{cluster_user}@{hostname}"
+    if tunnel_host and "@" not in tunnel_host and tunnel_host_user:
+        tunnel_host = f"{tunnel_host_user}@{tunnel_host}"
+
     kernel_name, _ = add_kernel(
         interface="ssh",
         name=KERNEL_NAME,
@@ -79,6 +108,7 @@ def add_remote_kernel(hostname, cluster_uuid, ssh_key_fname=None, dryrun=False):
         launch_args=f"-i {ssh_key_fname}" if ssh_key_fname else None,
         kerneldir=KERNEL_DIR,
         dryrun=dryrun,
+        tunnel_hosts=[tunnel_host] if tunnel_host else None,
         metadata={
             KERNEL_METADATA_CLUSTER_UUID_FIELD: cluster_uuid,
             KERNEL_METADATA_HOSTNAME_FIELD: hostname,
