@@ -60,20 +60,15 @@ export class ContentFactoryWithSelect extends NotebookPanel.ContentFactory {
 
   createCellHeader(): ICellHeader {
     if (this.RENDER_HEADER) {
-      return new CellHeaderWithSelect();
+      return new CellHeaderWithSelect(this._CATALOG_MODE);
     }
 
     return new CellHeader();
   }
 
   createCodeCell(options: CodeCell.IOptions, parent: StaticNotebook): CodeCell {
-    // render the language selector if catalog mode is enabled.
-    this.RENDER_HEADER = this._CATALOG_MODE;
-    if (this._CATALOG_MODE) {
-      return new PythonSQLCodeCell(options, parent.model?.metadata.get('bodo-catalog'));
-    } else {
-      return new CodeCell(options);
-    }
+    this.RENDER_HEADER = true;
+    return new PythonSQLCodeCell(options, parent.model?.metadata.get('bodo-catalog'));
   }
 
   createMarkdownCell(options: MarkdownCell.IOptions, parent: StaticNotebook): MarkdownCell {
@@ -166,8 +161,9 @@ export class CellHeaderWithSelect extends ReactWidget implements ICellHeader {
   _output = '';
 
   private _isSelecting = false;
+  private catalogMode: boolean | null = false;
 
-  constructor() {
+  constructor(catalogMode: boolean | null = false) {
     super();
 
     this.handleToggle = this.handleToggle.bind(this);
@@ -175,6 +171,7 @@ export class CellHeaderWithSelect extends ReactWidget implements ICellHeader {
     this.setLangPython = this.setLangPython.bind(this);
     this.setLangSQL = this.setLangSQL.bind(this);
     this.setLang = this.setLang.bind(this);
+    this.catalogMode = catalogMode;
   }
 
   handleToggle(): void {
@@ -238,9 +235,11 @@ export class CellHeaderWithSelect extends ReactWidget implements ICellHeader {
               >
                 Parallel-Python
               </option>
-              <option value={SupportedLanguages.SQL} selected={SupportedLanguages.SQL === lang}>
-                SQL
-              </option>
+              {this.catalogMode ? (
+                <option value={SupportedLanguages.SQL} selected={SupportedLanguages.SQL === lang}>
+                  SQL
+                </option>
+              ) : null}
               <option
                 value={SupportedLanguages.PYTHON}
                 selected={SupportedLanguages.PYTHON === lang}
