@@ -3,10 +3,10 @@ import { ClusterStore } from './store';
 import { ToolbarExtension } from './toolbar';
 import { cellFactory } from './cellSelect';
 import '../style/index.css';
-
 import { LabIcon } from '@jupyterlab/ui-components';
 import logoSvgStr from '../style/bodo-icon-green.svg';
 import { BodoClusterListSidebar } from './sidebar';
+import { plugin as terminalExtension } from './clusterTerminal/clusterTerminalExtension';
 
 const activate = (app: JupyterFrontEnd, labShell: ILabShell): void => {
   console.log('Bodo JupyterLab extension activated!');
@@ -16,7 +16,7 @@ const activate = (app: JupyterFrontEnd, labShell: ILabShell): void => {
   // Toolbar (select cluster from inside notebook)
   app.docRegistry.addWidgetExtension('Notebook', new ToolbarExtension(_cluster_store, null));
   // Sidebar to display clusters
-  const sidebar = new BodoClusterListSidebar(_cluster_store);
+  const sidebar = new BodoClusterListSidebar(_cluster_store, app);
   sidebar.id = 'bodo-cluster-list';
   sidebar.title.icon = new LabIcon({
     name: 'bodo_jupyterlab:logo',
@@ -37,6 +37,7 @@ const plugins: JupyterFrontEndPlugin<any>[] = [
     requires: [ILabShell],
     activate,
   },
+  terminalExtension,
   cellFactory,
 ];
 
