@@ -3,7 +3,7 @@ import { Poll } from '@lumino/polling';
 import { Signal, ISignal } from '@lumino/signaling';
 import { CLUSTER_LIST_REFRESH_SECONDS } from './config';
 import { ICluster } from './types';
-import { getClusterListHandler } from './handler';
+import { getClusterListHandler, refreshClusterListHandler } from './handler';
 import { showErrorMessage } from '@jupyterlab/apputils';
 
 class ClusterStore {
@@ -16,13 +16,13 @@ class ClusterStore {
   constructor() {
     this._clusters = [];
     // Initial update
-    void this.updateClusters();
+    void this.updateClusters(false);
 
     this._clusterChanged = new Signal<this, IChangedArgs<ICluster[] | undefined>>(this);
 
     this._poll = new Poll({
       factory: async () => {
-        await this.updateClusters();
+        await this.updateClusters(false);
       },
       frequency: {
         interval: CLUSTER_LIST_REFRESH_SECONDS * 1000,
@@ -43,19 +43,35 @@ class ClusterStore {
     return this._clusterChanged;
   }
 
-  private async getClustersList(): Promise<ICluster[]> {
+  private async getClustersList(refreshClusters = false): Promise<ICluster[]> {
     try {
-      return (await getClusterListHandler()) as ICluster[];
+      if (refreshClusters) {
+        return (await refreshClusterListHandler()) as ICluster[];
+      } else {
+        return (await getClusterListHandler()) as ICluster[];
+      }
     } catch (e) {
       console.error('Error in ClusterStore.getClustersList: ', e);
       if (!this._clusterListErrorShown) {
-        showErrorMessage('Bodo Extension Errror: Unable to get cluster list', e);
+        showErrorMessage('Bodo Extension Error: Unable to get cluster list', e);
         this._clusterListErrorShown = true;
       }
       return [];
     }
   }
 
+  async forceUpdate(): Promise<void> {
+    try {
+      await this.updateClusters(true);
+    } catch (e) {
+      console.error('Error in ClusterStore.forceUpdate: ', e);
+      if (!this._clusterListErrorShown) {
+        showErrorMessage('Bodo Extension Error: Unable to get cluster list', e);
+        this._clusterListErrorShown = true;
+      }
+    }
+  }
+
   private clusterListHasChanged(oldList: ICluster[], newList: ICluster[]): boolean {
     if (oldList.length !== newList.length) {
       return true;
@@ -72,9 +88,8 @@ class ClusterStore {
     return false;
   }
 
-  private async updateClusters(): Promise<void> {
-    const newClusters: ICluster[] = await this.getClustersList();
-
+  private async updateClusters(refreshClusters = false): Promise<void> {
+    const newClusters: ICluster[] = await this.getClustersList(refreshClusters);
     // Only emit a signal if the list has changed or it's the first call
     if (this.clusterListHasChanged(this._clusters, newClusters)) {
       this._clusterChanged.emit({
